# frozen_string_literal: true

require "refinements/pathnames"

module FLACsmith
  module CLI
    module Actions
      # Handles the list action.
      class List
        include FLACsmith::Import[:logger]

        using Refinements::Pathnames

        def initialize tagger: Metadata::Tagger, **dependencies
          super(**dependencies)
          @tagger = tagger
        end

        def call source_dir
          Pathname(source_dir).files("**/*.flac").each do |path|
            logger.info { "FILE = #{path}" }
            tag path
          end
        end

        private

        attr_reader :tagger

        def tag path
          tagger.new(path).read.map { |key, value| logger.info { "#{key} = #{value}" } }
        end
      end
    end
  end
end
