# frozen_string_literal: true

require "refinements/pathnames"

module FLACsmith
  module CLI
    module Actions
      # Handles the rebuild action.
      class Rebuild
        include FLACsmith::Import[:logger]

        using Refinements::Pathnames

        def initialize builder: Metadata::Builder, **dependencies
          super(**dependencies)
          @builder = builder
        end

        def call source_dir
          logger.info { "Rebuilding metadata for: #{source_dir}..." }
          build source_dir
        end

        private

        attr_reader :builder

        def build root
          builder.new(Pathname(root))
                 .then { |instance| instance.tap(&:call) }
                 .paths
                 .each { |path| logger.info { "Processed: #{path}" } }
        end
      end
    end
  end
end
