# frozen_string_literal: true

require "refinements/structs"

module FLACsmith
  module CLI
    module Parsers
      # Handles parsing of Command Line Interface (CLI) core options.
      class Core
        include Import[:specification]

        using Refinements::Structs

        def self.call(...) = new(...).call

        def initialize configuration = Container[:configuration],
                       client: Parser::CLIENT,
                       **dependencies
          super(**dependencies)
          @configuration = configuration
          @client = client
        end

        def call arguments = []
          client.banner = specification.labeled_summary
          client.separator "\nUSAGE:\n"
          collate
          client.parse arguments
          configuration
        end

        private

        attr_reader :configuration, :client

        def collate = private_methods.sort.grep(/add_/).each { |method| __send__ method }

        def add_encode
          client.on(
            "-e",
            "--encode SOURCE_DIR,TARGET_DIR",
            "Encode source audio as FLAC audio."
          ) do |paths|
            source_dir, target_dir = paths.split ","
            configuration.merge! action_encode: true, source_dir:, target_dir:
          end
        end

        def add_list
          client.on(
            "-l",
            "--list SOURCE_DIR",
            "List track metadata for source directory."
          ) do |source_dir|
            configuration.merge! action_list: true, source_dir:
          end
        end

        def add_rebuild
          client.on(
            "-r",
            "--rebuild SOURCE_DIR",
            "Rebuild track metadata for source directory."
          ) do |source_dir|
            configuration.merge! action_rebuild: true, source_dir:
          end
        end

        def add_version
          client.on "-v", "--version", "Show gem version." do
            configuration.merge! action_version: true
          end
        end

        def add_help
          client.on "-h", "--help", "Show this message." do
            configuration.merge! action_help: true
          end
        end
      end
    end
  end
end
