# frozen_string_literal: true

module FLACsmith
  module CLI
    # The main Command Line Interface (CLI) object.
    class Shell
      include Actions::Import[:encode, :list, :rebuild, :specification, :logger]

      def initialize parser: Parser.new, **dependencies
        super(**dependencies)
        @parser = parser
      end

      def call arguments = []
        perform parser.call(arguments)
      rescue OptionParser::ParseError => error
        logger.error { error.message }
      end

      private

      attr_reader :parser

      def perform configuration
        case configuration
          in action_encode: true, source_dir:, target_dir:, image_path:
            encode.call source_dir, target_dir, image_path:
          in action_list: true, source_dir: then list.call source_dir
          in action_rebuild: true, source_dir: then rebuild.call source_dir
          in action_version: true then logger.info { specification.labeled_version }
          else logger.any { parser.to_s }
        end
      end
    end
  end
end
